/*
 * Project: VizKit
 * Version: 3.3.7
 
 * Date: 20150503
 * File: VisualConfigurationDialog.cpp
 *
 */

/***************************************************************************

Copyright (c) 2004-2015 Heiko Wichmann (http://www.imagomat.de/vizkit)


This software is provided 'as-is', without any expressed or implied warranty. 
In no event will the authors be held liable for any damages
arising from the use of this software.

Permission is granted to anyone to use this software for any purpose,
including commercial applications, and to alter it and redistribute it
freely, subject to the following restrictions:

1. The origin of this software must not be misrepresented; 
   you must not claim that you wrote the original software. 
   If you use this software in a product, an acknowledgment 
   in the product documentation would be appreciated 
   but is not required.

2. Altered source versions must be plainly marked as such, 
   and must not be misrepresented as being the original software.

3. This notice may not be removed or altered from any source distribution.

 ***************************************************************************/

#include "VisualConfigurationDialog.h"
#include "VisualErrorHandling.h"

#if TARGET_OS_WIN
#include "VisualPropertySheet.h"
#endif

#if TARGET_OS_MAC
// file type of VisualGraphicsCore.cpp is set to "Objective-C++ source"
#import "OptionsDialogWindowController.h"
#endif


using namespace VizKit;


VisualConfigurationDialog* VisualConfigurationDialog::visualConfigurationDialogInstance = NULL;



VisualConfigurationDialog::VisualConfigurationDialog()
{
#if TARGET_OS_MAC
    optionsDialogWindowController = NULL;
#endif
}


VisualConfigurationDialog::~VisualConfigurationDialog()
{
#if TARGET_OS_MAC
    [optionsDialogWindowController release];
    optionsDialogWindowController = NULL;
#endif
}


VisualConfigurationDialog* VisualConfigurationDialog::getInstance(void)
{
    if (visualConfigurationDialogInstance == NULL)
    {
        visualConfigurationDialogInstance = new VisualConfigurationDialog;
        if (visualConfigurationDialogInstance == NULL) 
        {
            char errLog[512];
            sprintf(errLog, "ERR: init VisualConfigurationDialog failed in file: %s (line: %d) [%s])", __FILE__, __LINE__, __FUNCTION__);
            writeLog(errLog);
        }
    }
#if TARGET_OS_MAC
    if (visualConfigurationDialogInstance && visualConfigurationDialogInstance->optionsDialogWindowController == NULL)
    {
        visualConfigurationDialogInstance->optionsDialogWindowController = [[OptionsDialogWindowController alloc] init];
    }
#endif
    return visualConfigurationDialogInstance;
}


void VisualConfigurationDialog::show() 
{
#if TARGET_OS_WIN
	AFX_MANAGE_STATE(AfxGetStaticModuleState());
	CVisualPropertySheet* thePropertySheet = CVisualPropertySheet::getInstance();
	if (thePropertySheet != NULL) {
		thePropertySheet->BringWindowToTop();
	}
#endif
#if TARGET_OS_MAC
    VisualConfigurationDialog *theVisualConfigurationDialog = VisualConfigurationDialog::getInstance();
    if (theVisualConfigurationDialog)
    {
        [theVisualConfigurationDialog->optionsDialogWindowController showWindow:nil];
        [[theVisualConfigurationDialog->optionsDialogWindowController window] makeKeyAndOrderFront:[[NSApplication sharedApplication] keyWindow]];
    }
#endif
}


void VisualConfigurationDialog::dispose() 
{
#if TARGET_OS_WIN
	CVisualPropertySheet::dispose();
#endif
#if TARGET_OS_MAC
    if (visualConfigurationDialogInstance != NULL)
    {
        delete visualConfigurationDialogInstance;
        visualConfigurationDialogInstance = NULL;
    }
#endif
}


#if TARGET_OS_MAC
void VisualConfigurationDialog::resetOptionsDialogWindowController()
{
    VisualConfigurationDialog *theVisualConfigurationDialog = VisualConfigurationDialog::getInstance();
    if (theVisualConfigurationDialog)
    {
        theVisualConfigurationDialog->optionsDialogWindowController = NULL;
    }
}
#endif
