/*
 * Project: VizKit
 * Version: 3.3.7
 
 * Date: 20150503
 * File: VisualConfigurationDialog.h
 *
 */

/***************************************************************************

Copyright (c) 2004-2015 Heiko Wichmann (http://www.imagomat.de/vizkit)


This software is provided 'as-is', without any expressed or implied warranty. 
In no event will the authors be held liable for any damages
arising from the use of this software.

Permission is granted to anyone to use this software for any purpose,
including commercial applications, and to alter it and redistribute it
freely, subject to the following restrictions:

1. The origin of this software must not be misrepresented; 
   you must not claim that you wrote the original software. 
   If you use this software in a product, an acknowledgment 
   in the product documentation would be appreciated 
   but is not required.

2. Altered source versions must be plainly marked as such, 
   and must not be misrepresented as being the original software.

3. This notice may not be removed or altered from any source distribution.

 ***************************************************************************/

#ifndef VisualConfigurationDialog_h
#define VisualConfigurationDialog_h

#include "VisualTypes.h"

#if TARGET_OS_MAC
#include "VisualCustomization.h"
#ifdef __OBJC__
@class OptionsDialogWindowController;
#else
struct OptionsDialogWindowController;
#endif
#endif

namespace VizKit {
	
	/** Wrapper around OS specific UI implementations of the configuration dialog. */
	class VisualConfigurationDialog {
	
	public:

		/**
		 * Displays the OS specific UI of the configuration dialog.
		 * @remarks In case the dialog was visible already, it is brought to front.
		 */
		static void show(void);

		/** Disposes the OS specific UI resources of the configuration dialog. */
		static void dispose(void);
        
#if TARGET_OS_MAC
        /**
		 * Resets the options dialog window controller.
		 */
        static void resetOptionsDialogWindowController(void);
#endif

	private:
        
        /**
		 * Constructs a VisualConfigurationDialog. The VisualConfigurationDialog acts as a singleton. Returns a pointer to the initialised VisualConfigurationDialog.
		 * @return A pointer to the singleton instance.
		 */
		static VisualConfigurationDialog* getInstance(void);

		/** VisualConfigurationDialog is a singleton class. Pointer to private instance is handled internally. */
		static VisualConfigurationDialog* visualConfigurationDialogInstance;
        
		/** The constructor. VisualConfigurationDialog is a singleton class. The constructor is private. New instance of class can only be created internally. */
		VisualConfigurationDialog();
		
		/** The destructor. VisualConfigurationDialog is a singleton class. The destructor is private. Instance of class can only be destructed internally. */
		~VisualConfigurationDialog();
        
		/**
		 * Copy constructor.
		 * @param other Another VisualConfigurationDialog.
		 * @remarks Explicitely declared in private section and not implemented to enforce uniqueness of singleton pattern.
		 */
		VisualConfigurationDialog(const VisualConfigurationDialog& other);
        
		/**
		 * Assignment operator.
		 * @remarks Explicitely declared in private section and not implemented to enforce uniqueness of singleton pattern.
		 */			
		VisualConfigurationDialog& operator=(const VisualConfigurationDialog& other);

#if TARGET_OS_MAC
        OptionsDialogWindowController *optionsDialogWindowController;
#endif
		
	};

}

#endif /* VisualConfigurationDialog_h */

